==> test-envelope-ui-0.0.32.tgz: package/es/menu/menu.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  &&& {\n    list-style: none;\n    line-height: 2.5em;\n    padding: 0.5em;\n    margin: 0;\n    display: inline-flex;\n  }\n'], ['\n  &&& {\n    list-style: none;\n    line-height: 2.5em;\n    padding: 0.5em;\n    margin: 0;\n    display: inline-flex;\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React from 'react';
import styled, { ThemeContext } from 'styled-components';
import PropTypes from 'prop-types';

import { themeProps, clutchd } from '../themed/themes';
import { getTheme } from '../themed/utils';

var propTypes = {
  theme: themeProps
};

var defaultProps = {
  theme: clutchd.theme
};

var StyledMenu = styled.ul(_templateObject);

/**
 * The `Menu` component is meant to be used as a navigation component to allow for quick menu building.
 */
var Menu = function Menu(_ref) {
  var theme = _ref.theme,
      loading = _ref.loading,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['theme', 'loading', 'children']);

  var currentTheme = getTheme(ThemeContext, theme);

  return React.createElement(
    StyledMenu,
    _extends({ theme: currentTheme }, props),
    loading ? children : React.createElement(
      React.Fragment,
      null,
      children
    )
  );
};

Menu.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Menu.defaultProps = defaultProps;

export default Menu;

==> test-envelope-ui-0.0.40.tgz: package/es/menu/menu.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  &&& {\n    list-style: none;\n    line-height: 2.5em;\n    padding: 0.5em;\n    margin: 0;\n    display: inline-flex;\n  }\n'], ['\n  &&& {\n    list-style: none;\n    line-height: 2.5em;\n    padding: 0.5em;\n    margin: 0;\n    display: inline-flex;\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React from 'react';
import styled, { ThemeContext } from 'styled-components';
import PropTypes from 'prop-types';

import { clutchd, themeProps } from '../style/themes';
import { getTheme } from '../style/utils';

var propTypes = {
  theme: themeProps
};

var defaultProps = {
  theme: clutchd
};

var StyledMenu = styled.ul(_templateObject);

/**
 * The `Menu` component is meant to be used as a navigation component to allow for quick menu building.
 */
var Menu = function Menu(_ref) {
  var theme = _ref.theme,
      loading = _ref.loading,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['theme', 'loading', 'children']);

  var currentTheme = getTheme(ThemeContext, theme);

  return React.createElement(
    StyledMenu,
    _extends({ theme: currentTheme }, props),
    loading ? children : React.createElement(
      React.Fragment,
      null,
      children
    )
  );
};

Menu.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Menu.defaultProps = defaultProps;

export default Menu;
